@@ -39,7 +39,12 @@ class Report(InfoReport):
         return actions
 
     def callback(self, data):
-        self.install_packages(["mint-meta-codecs", "libavcodec-extra", "libavcodec-extra59"])
+        if os.path.exists("/usr/share/doc/debian-system-adjustments/copyright"):
+            # LMDE 6
+            self.install_packages(["mint-meta-codecs", "libavcodec-extra", "libavcodec-extra59"])
+        else:
+            # Mint 21.x
+            self.install_packages(["mint-meta-codecs", "libavcodec-extra", "libavcodec-extra58"])
         # reload
         return True
 
